/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package application.graphics.center;

import application.Main;
import application.graphics.utility.PopupCreator;
import java.util.ArrayList;
import javafx.beans.property.IntegerPropertyBase;
import javafx.beans.property.SimpleIntegerProperty;
import javafx.event.EventHandler;
import javafx.geometry.Bounds;
import javafx.scene.input.MouseEvent;
import javafx.scene.layout.Pane;
import javafx.scene.layout.Region;

/**
 *
 * @author sci-esame
 */
public class Panel extends Pane {

    private int dadoCounter;
    private static boolean win = false;

    /**
     * Rappresenta la lista di dadi presenti
     */
    public static final ArrayList<Dado> dadi = new ArrayList<>();

    /**
     * Il totale raggiunto
     */
    public static final IntegerPropertyBase total = new SimpleIntegerProperty();

    /**
     * Il punteggio raggiunto
     */
    public static final IntegerPropertyBase points = new SimpleIntegerProperty(30);

    public int getPoints() {
        return points.get();
    }

    public void setPoints(int value) {
        points.set(value);
    }

    public IntegerPropertyBase pointsProperty() {
        return points;
    }

    public int getTotal() {
        return total.get();
    }

    public void setTotal(int value) {
        total.set(value);
    }

    public IntegerPropertyBase totalProperty() {
        return total;
    }

    /**
     * Il pannello verde dove ci sono i dadi
     *
     * @param parent La Region che contiene il pannello
     */
    public Panel(Region parent) {
        this.setStyle("-fx-background-color:green; -fx-border-color:black;");
        addHandler();
    }

    /**
     * Aggiunge un dado al pannello, se ce ne sono meno di 6
     *
     * @param d Il dado da aggiungere
     * @return true se il dado è stato aggiunto
     */
    public boolean addDado(Dado d) {
        if (dadoCounter < 5) {
            this.getChildren().add(d);
            dadoCounter++;
            dadi.add(d);
            updateTotal(d.getValue());
            return true;
        } else {
            PopupCreator.showPopup("Numero massimo di dadi raggiunto!", Main.stg, false);
            return false;
        }
    }

    private static void updateTotal(int aggiungi) {
        total.set(total.get() + aggiungi);
        if (total.get() == 15) {
            PopupCreator.showPopup("Hai vinto! Hai ottenuto " + points.get() + " punti!", Main.stg, false);
            win = true;
        }
    }

    private void addHandler() {
        this.setOnMouseClicked(new EventHandler<MouseEvent>() {

            Dado clickedDado;

            @Override
            public void handle(MouseEvent event) {
                boolean checkBoundaries = checkBoundaries(event);

                if (checkBoundaries) {
                    Dado d = new Dado(Panel.this, event);
                    if (Panel.this.addDado(d)) {
                        points.set(points.get() - 3);
                    }
                } else {
                    updateTotal(-clickedDado.getValue());
                    clickedDado.newFace();
                    points.set(points.get() - 1);
                    updateTotal(clickedDado.getValue());
                }
            }

            private boolean checkBoundaries(MouseEvent event) {
                boolean notCollision = true;
                for (Dado dado : dadi) {
                    Bounds dadoBounds = dado.getBoundsInParent();
                    if (dadoBounds.contains(event.getX(), event.getY())) {
                        notCollision = false;
                        clickedDado = dado;
                    }
                }
                return notCollision;
            }
        });
        this.addEventFilter(MouseEvent.MOUSE_CLICKED, new EventHandler<MouseEvent>() {

            @Override
            public void handle(MouseEvent event) {
                if (win) {
                    PopupCreator.showPopup("Partita terminata!", Main.stg, true);
                    event.consume();
                }
            }
        });
    }

    /**
     * Ripristina le condizioni iniziali nel pannello verde
     */
    public void reset() {
        this.getChildren().clear();
        dadi.clear();
        win = false;
        dadoCounter = 0;
        total.set(0);
        points.set(30);
    }
}
