package application.graphics.utility;

import javafx.scene.layout.StackPane;
import javafx.scene.paint.Color;
import javafx.scene.shape.Rectangle;
import javafx.scene.text.Font;
import javafx.scene.text.FontWeight;
import javafx.scene.text.Text;
import javafx.stage.Popup;
import javafx.stage.Stage;

/**
 *
 * @author carlo.mion
 */
public class PopupCreator {

    /**
     * Funzione richiamabile per avere un popup con del testo. <br>
     *
     * Il testo può essere informativo o un messaggio di errore. Serve uno stage
     * a cui assegnarlo <br>
     * Il popup si autochiude quando l'utente interagisce con qualunque parte
     * della finestra
     *
     * @param message Il messaggio da visualizzare a schermo
     * @param owner È necessario uno stage attivo per mostrare il popup
     * @param isError Se il messaggio è di errore o di informazione <br>
     * Nel primo caso sarà scritto in rosso con bordo accentuato, mentre
     * nell'altro in nero
     */
    public static void showPopup(final String message, final Stage owner, boolean isError) {
        Popup p = new Popup();

        StackPane root = new StackPane();

        Rectangle rect = new Rectangle();
        rect.setArcHeight(20);
        rect.setArcWidth(20);
        rect.setFill(Color.LIGHTCYAN);

        Text messageText = new Text(message);
        if (isError) {
            messageText.setFill(Color.RED);
            messageText.setFont(Font.font("Arial", FontWeight.BOLD, 20));
        } else {
            messageText.setFont(Font.font("Times", 20));
        }

        root.getChildren().addAll(rect, messageText);

        double x = messageText.getBoundsInParent().getMaxX() + 10;
        double y = messageText.maxHeight(x) + 10;
        rect.setWidth(x);
        rect.setHeight(y);

        p.getContent().add(root);
        p.setAutoHide(true);

        double xlocation = owner.getWidth() / 2.0 - p.getWidth() / 2.0 + owner.getX();
        double ylocation = owner.getHeight() / 2.0 - p.getHeight() / 2.0 + owner.getY();

        p.show(owner, xlocation, ylocation);

    }
}
